Learn R Programming

arulesNBMiner (version 0.1-2)

NBMinerParameters: Estimate Global Model Parameters from Data

Description

Estimate the global negative binomial data model used by the NBMiner and create an appropriate parameter object.

Usage

NBMinerParameters(data, trim = 0.01, pi = 0.99, theta = 0.5,
    minlen = 1, maxlen = 5, rules = FALSE,
    plot = FALSE, verbose = FALSE, getdata = FALSE)

Arguments

Value

an object of class NBMinerParameter for NBMiner.

Details

Uses the EM algorithm to estimate the global NB model for the data. The EM algorithm is used since the zero class (items which do not occur in the dataset) is not included in the data. The result are the two NB parameters $k$ and $a$, where $a$ is rescaled by dividing it by the number of incidences in the data (this is needed by the NBMiner). Also the real number of items $n$ is a result of the estimation.

theta and pi are just taken and added to the resulting parameter object.

References

Michael Hahsler. A model-based frequency constraint for mining associations from transaction data. Data Mining and Knowledge Discovery,13(2):137-166, September 2006.

See Also

NBMiner, transactions-class

Examples

Run this code
data("Epub")

param <- NBMinerParameters(Epub, trim = 0.001, plot = TRUE, verbose = TRUE)
param

Run the code above in your browser using DataLab