Uses the EM algorithm to estimate the global NB model for the data.
The EM algorithm is used since the zero class (items which do not occur
in the dataset) is not included in the data. The result are the two
NB parameters $k$ and $a$, where $a$ is rescaled by dividing
it by the number of incidences in the data (this is needed by the NBMiner).
Also the real number of items $n$ is a result of the estimation.
theta and pi are just taken and added to the resulting
parameter object.
References
Michael Hahsler. A model-based frequency constraint for mining associations
from transaction data. Data Mining and Knowledge
Discovery,13(2):137-166, September 2006.